@@ -24,7 +24,7 @@ class Text:
             self.file = open(path, mode=mode, encoding=encoding)
         except PermissionError as e:
             print("error message printed in std.file:", e)
-            exit(0)
+            raise e
         except FileNotFoundError:
             createNewFile(path)
             self.file = open(path, "w+", encoding=encoding)
